import traymodule
from trayutilities import *
import gobject
import subprocess
import pango

class Macopix(traymodule.TrayModule):
	configspec={
			'macopix-step': 'integer(default=0)',
			'macopix-default-timeout': 'integer(default=5000)',
			'macopix-force-default-timeout': 'boolean(default=False)'
	}
	def __init__(self, parentIn):
		traymodule.TrayModule.__init__(self, parentIn)
	def add_popup_providers(self):
		self.parent.module_add_popup_provider(self.create_popup, self.destroy_popup)
	def configure(self):
		config = self.get_config()
		self.macopix_step = config.get_value('macopix-step')
		self.macopix_default_timeout = config.get_value('macopix-default-timeout')
		self.macopix_force_default_timeout = config.get_value('macopix-force-default-timeout')
	def create_popup(self, module_name, title=None, markup=None, icon=None, lifetime=5000, id=None, on_click=None):
		if title and markup:
			title = self.strip(title)
			markup = self.strip(markup)
			message = title + "\r" + markup
		elif markup:
			markup = self.strip(markup)
			message = markup
		elif title:
			title = self.strip(title)
			message = title
		else:
			self.destroy_popup(module_name, id)
			return
		if (lifetime == 0) | self.macopix_force_default_timeout:
			lifetime = self.macopix_default_timeout
		self.parent.debug_msg("Running macopix ...")
		if self.macopix_step:
			subprocess.Popen(["macopix","--message-expire","%s"%(lifetime),"--message",message,"--message-step","%s"%(self.macopix_step)])
		else:
			subprocess.Popen(["macopix","--message-expire","%s"%(lifetime),"--message",message])
		gobject.timeout_add(lifetime, self.destroy_popup, module_name, id)
	def destroy_popup(self, module_name, popup_id):
		# Macopix can't destroy popups.
		self.parent.popup_destroyed(module_name, popup_id)
	def safe_strip(self, s):
		s = s.replace('<b>', '')
		s = s.replace('</b>', '')
		s = s.replace('<i>', '')
		s = s.replace('</i>', '')
		s = s.replace('<u>', '')
		s = s.replace('</u>', '')
		s = s.replace('&apos;', '')
		s = s.replace('&lt;', '<')
		s = s.replace('&gt;', '>')
		s = s.replace('&amp;', '&')
		s = s.rstrip('\n')
		return s
	def strip(self, s):
		s = s.rstrip('\n')
		try:
			tmp_s = pango.parse_markup(s)
		except:
			return self.safe_strip(s)
		return tmp_s[1]


modulename = Macopix
